# import subprocess
# import os
# subprocess.call("f2py -c -m grids_read_f grids_read.F90", shell=True)
# subprocess.call("f2py -c -m snap_read_f snap_read.F90", shell=True)

import snap_read_f
import grids_read_f
import numpy as np
import matplotlib
from matplotlib import pyplot as plt
from mpl_toolkits.mplot3d import Axes3D
import matplotlib.tri as mtri
import argparse
import os


def mask_func(x,y,limit):
    distance0=np.sqrt((x[:,1]-x[:,0])**2+(y[:,1]-y[:,0])**2)
    distance1=np.sqrt((x[:,2]-x[:,1])**2+(y[:,2]-y[:,1])**2)
    distance2=np.sqrt((x[:,0]-x[:,2])**2+(y[:,0]-y[:,2])**2)

    return np.max(np.array([distance0,distance1,distance2]), axis=0) > limit

def main(step, numerfrc, directory='.'):
    directory = os.path.abspath(directory)
    snap_file_name = os.path.join(directory, "frc_CYL_snapshot%07d.out" % step)
    snap_read_f.snap_parameters.filename(snap_file_name)
    snap_read_f.snap_parameters.numerfrc = numerfrc
    snap_read_f.snap_parameters.snap_read()
    grids_file_name = os.path.join(directory, "grids.out")
    grids_read_f.grids_parameters.filename(grids_file_name)
    grids_read_f.grids_parameters.numerfrc = numerfrc
    grids_read_f.grids_parameters.grids_read()
    print('mgrid_core:', grids_read_f.grids_parameters.mgrid_core,
          'mgrid_sol:', len(grids_read_f.grids_parameters.rsol))
    if numerfrc==1:
        r_all = np.concatenate(
            (grids_read_f.grids_parameters.rcore, grids_read_f.grids_parameters.rsol))
        z_all = np.concatenate(
            (grids_read_f.grids_parameters.zcore, grids_read_f.grids_parameters.zsol))
    elif numerfrc==3:
        r_all = grids_read_f.grids_parameters.rsol
        z_all = grids_read_f.grids_parameters.zsol
    phi = snap_read_f.snap_parameters.phi
    ni = snap_read_f.snap_parameters.densityi
    print(phi[165], ni[165])
    triang = mtri.Triangulation(r_all, z_all)
    triang.set_mask(mask_func(r_all[triang.triangles],z_all[triang.triangles],0.5))
    #fig0 = plt.figure()
    #ax = fig0.add_subplot(111)
    #tpc = ax.triplot(triang)
    #ax.set_title('grids')
    # ax.axis('equal')

    fig1 = plt.figure()
    ax = fig1.add_subplot(121)
    tpc = ax.tripcolor(triang, ni, shading='flat', cmap='jet')
    ax.set_title('delta n_i')
    fig1.colorbar(tpc)
    ax2 = fig1.add_subplot(122)
    tpc2 = ax2.tripcolor(triang, ni, shading='flat', cmap='jet')
    ax2.axis('equal')

    fig2 = plt.figure()
    ax = fig2.add_subplot(121)
    tpc = ax.tripcolor(triang, phi, shading='flat', cmap='jet')
    ax.set_title('phi')
    fig2.colorbar(tpc)
    ax2 = fig2.add_subplot(122)
    tpc2 = ax2.tripcolor(triang, phi, shading='flat', cmap='jet')
    ax2.axis('equal')
    plt.show()


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("--dir",action='store',default='.')
    parser.add_argument("--step","-s", type=int)
    parser.add_argument("--numerfrc","-n", type=int, default=1)
    args = parser.parse_args()
    main(args.step, args.numerfrc,args.dir)
